cgexplore.forcefields.AssignedSystem
====================================

.. currentmodule:: cgexplore.forcefields

.. autoclass:: AssignedSystem
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~AssignedSystem.get_openmm_system
      ~AssignedSystem.get_openmm_topology
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AssignedSystem.molecule
      ~AssignedSystem.forcefield_terms
      ~AssignedSystem.system_xml
      ~AssignedSystem.topology_xml
      ~AssignedSystem.bead_set
      ~AssignedSystem.vdw_bond_cutoff
      ~AssignedSystem.mass
   
   